starcluster.commands.showimage

Package starcluster :: Package commands :: Module showimage |
[hide private]
[frames] | no frames]

# Source Code for Module starcluster.commands.showimage

     1  #!/usr/bin/env python
     2
     3  #from base import CmdBase
     4  from downloadimage import CmdDownloadImage
     5
     6
     7 -class CmdShowImage(CmdDownloadImage):
     8      """
     9      showimage <image_id>
    10
    11      Show all AMI parts and manifest files on S3 for an instance-store AMI
    12
    13      Example:
    14
    15          $ starcluster showimage ami-999999
    16      """
    17      names = ['showimage', 'shimg']
    18
    19 -    def execute(self, args):
    20          if not args:
    21              self.parser.error('please specify an AMI id')
    22          for arg in args:
    23              self.ec2.list_image_files(arg)
    24